@@ -18,169 +18,16 @@ amu_gm = 1.66054e-24
 ang_cm = 1e-8
 
 
-class VacuumPadding(object):
-    """
-    Adds vaccum padding to make 2D structure or making molecules
-
-    """
-
-    def __init__(self, atoms, vacuum=20.0):
-        self.atoms = atoms
-        self.vacuum = vacuum
-
-    def get_effective_2d_slab(self):
-        """
-        Adds 2D vacuum to a system
-        """
-        z_coord = []
-        for i in self.atoms.frac_coords:
-            tmp = i[2]
-            if i[2] >= 0.5:
-                tmp = i[2] - 1
-            elif i[2] < -0.5:
-                tmp = i[2] + 1
-            z_coord.append(tmp)
-
-        zmaxp = max(np.array(z_coord) * self.atoms.lattice_mat[2][2])
-        zminp = min(np.array(z_coord) * self.atoms.lattice_mat[2][2])
-        thickness = abs(zmaxp - zminp)
-        padding = self.vacuum + thickness
-
-        lattice_mat = self.atoms.lattice_mat
-        # lattice_mat[2][2] = padding
-        # elements = self.atoms.elements
-        # atoms = Atoms(lattice_mat = lattice_mat, coords = self.atoms.cart_coords, elements = elements, cartesian = True)
-        # atoms = atoms.center(vacuum=0.0)
-        new_lat = self.atoms.lattice_mat
-        a1 = new_lat[0]
-        a2 = new_lat[1]
-        a3 = new_lat[2]
-        new_lat = np.array(
-            [
-                a1,
-                a2,
-                np.cross(a1, a2)
-                * np.dot(a3, np.cross(a1, a2))
-                / norm(np.cross(a1, a2)) ** 2,
-            ]
-        )
-
-        a1 = new_lat[0]
-        a2 = new_lat[1]
-        a3 = new_lat[2]
-        # print("a1,a2,a3", new_lat)
-
-        latest_lat = np.array(
-            [
-                (np.linalg.norm(a1), 0, 0),
-                (
-                    np.dot(a1, a2) / np.linalg.norm(a1),
-                    np.sqrt(
-                        np.linalg.norm(a2) ** 2
-                        - (np.dot(a1, a2) / np.linalg.norm(a1)) ** 2
-                    ),
-                    0,
-                ),
-                (0, 0, np.linalg.norm(a3)),
-            ]
-        )
-        # latest_lat[2][2] = padding
-        M = np.linalg.solve(new_lat, latest_lat)
-        new_cart_coords = self.atoms.cart_coords
-        new_coords = np.dot(new_cart_coords, M)
-        new_atoms = Atoms(
-            lattice_mat=latest_lat,
-            elements=self.atoms.elements,
-            coords=new_coords,
-            cartesian=True,
-        )
-        frac_coords = new_atoms.frac_coords
-        frac_coords[:] = frac_coords[:] % 1
-        new_atoms = Atoms(
-            lattice_mat=latest_lat,
-            elements=self.atoms.elements,
-            coords=frac_coords,
-            cartesian=False,
-        )
-        new_lat = new_atoms.lattice_mat
-        new_cart_coords = new_atoms.cart_coords
-        elements = new_atoms.elements
-        new_lat[2][2] = padding  # new_lat[2][2]+ self.vacuum
-        with_vacuum_atoms = Atoms(
-            lattice_mat=new_lat,
-            elements=elements,
-            coords=new_cart_coords,
-            cartesian=True,
-        )
-        frac = np.array(with_vacuum_atoms.frac_coords)
-        frac[:, 2] = frac[:, 2] - np.mean(frac[:, 2]) + 0.5
-        frac[:, 2] = frac[:, 2] - np.mean(frac[:, 2]) + 0.5
-        with_vacuum_atoms = Atoms(
-            lattice_mat=new_lat, elements=elements, coords=frac, cartesian=False
-        )
-        return with_vacuum_atoms
-
-    def get_effective_molecule(self):
-        """
-        Adds vacuum around a system
-        """
-        x_coord = []
-        y_coord = []
-        z_coord = []
-        for i in self.atoms.frac_coords:
-            tmp = i[0]
-            if i[0] >= 0.5:
-                tmp = i[0] - 1
-            elif i[0] < -0.5:
-                tmp = i[0] + 1
-            x_coord.append(tmp)
-            tmp = i[1]
-            if i[1] >= 0.5:
-                tmp = i[1] - 1
-            elif i[1] < -0.5:
-                tmp = i[1] + 1
-            y_coord.append(tmp)
-            tmp = i[2]
-            if i[2] >= 0.5:
-                tmp = i[2] - 1
-            elif i[2] < -0.5:
-                tmp = i[2] + 1
-            z_coord.append(tmp)
-
-        xmaxp = max(np.array(x_coord) * self.atoms.lattice_mat[0][0])
-        xminp = min(np.array(x_coord) * self.atoms.lattice_mat[0][0])
-        ymaxp = max(np.array(y_coord) * self.atoms.lattice_mat[1][1])
-        yminp = min(np.array(y_coord) * self.atoms.lattice_mat[1][1])
-        zmaxp = max(np.array(z_coord) * self.atoms.lattice_mat[2][2])
-        zminp = min(np.array(z_coord) * self.atoms.lattice_mat[2][2])
-        thickness_x = abs(xmaxp - xminp)
-        thickness_y = abs(ymaxp - yminp)
-        thickness_z = abs(zmaxp - zminp)
-
-        lattice_mat = np.zeros((3, 3))  # self.atoms.lattice_mat
-        lattice_mat[0][0] = self.vacuum + thickness_x
-        lattice_mat[1][1] = self.vacuum + thickness_y
-        lattice_mat[2][2] = self.vacuum + thickness_z
-        elements = self.atoms.elements
-        atoms = Atoms(
-            lattice_mat=lattice_mat,
-            coords=self.atoms.cart_coords,
-            elements=elements,
-            cartesian=True,
-        )
-        frac = np.array(atoms.frac_coords)
-        frac[:, 0] = frac[:, 0] - np.mean(frac[:, 0]) + 0.5
-        frac[:, 1] = frac[:, 1] - np.mean(frac[:, 1]) + 0.5
-        frac[:, 2] = frac[:, 2] - np.mean(frac[:, 2]) + 0.5
-        with_vacuum_atoms = Atoms(
-            lattice_mat=lattice_mat, elements=elements, coords=frac, cartesian=False
-        )
-        return with_vacuum_atoms
-
 
 class Atoms(object):
     def __init__(
-        self, lattice_mat=None, coords=None, elements=None, props=None, cartesian=False
+        self,
+        lattice_mat=None,
+        coords=None,
+        elements=None,
+        props=None,
+        cartesian=False,
+        show_props=False,
     ):
         """
         Create atomic structure with lattice, coordinates, atom type and other information
@@ -215,6 +62,7 @@ class Atoms(object):
         """
 
         self.lattice_mat = np.array(lattice_mat)
+        self.show_props = show_props
         self.lattice = Lattice(lattice_mat)
         self.coords = np.array(coords)
         self.elements = elements
@@ -547,19 +395,21 @@ class Atoms(object):
         """
         Adapted from Pymatgen
         Makes a supercell. Allowing to have sites outside the unit cell
+
         Args:
             scaling_matrix: A scaling matrix for transforming the lattice
-                vectors. Has to be all integers. Several options are possible:
-                a. A full 3x3 scaling matrix defining the linear combination
-                   the old lattice vectors. E.g., [[2,1,0],[0,3,0],[0,0,
-                   1]] generates a new structure with lattice vectors a' =
-                   2a + b, b' = 3b, c' = c where a, b, and c are the lattice
-                   vectors of the original structure.
-                b. An sequence of three scaling factors. E.g., [2, 1, 1]
-                   specifies that the supercell should have dimensions 2a x b x
-                   c.
-                c. A number, which simply scales all lattice vectors by the
-                   same factor.
+            vectors. Has to be all integers. Several options are possible:
+            a. A full 3x3 scaling matrix defining the linear combination
+             the old lattice vectors. E.g., [[2,1,0],[0,3,0],[0,0,
+             1]] generates a new structure with lattice vectors a' =
+             2a + b, b' = 3b, c' = c where a, b, and c are the lattice
+             vectors of the original structure.
+            b. An sequence of three scaling factors. E.g., [2, 1, 1]
+             specifies that the supercell should have dimensions 2a x b x
+             c.
+            c. A number, which simply scales all lattice vectors by the
+             same factor.
+
         Returns:
             Supercell structure. Note that a Structure is always returned,
             even if the input structure is a subclass of Structure. This is
@@ -647,7 +497,10 @@ class Atoms(object):
         """
         system = str(self.composition.reduced_formula)
         header = (
-            str(system)+str("\n1.0\n")
+
+            str(system)
+            + str("\n1.0\n")
+
             + str(self.lattice_mat[0][0])
             + " "
             + str(self.lattice_mat[0][1])
@@ -681,10 +534,14 @@ class Atoms(object):
         rest = ""
         # print ('repr',self.frac_coords, self.frac_coords.shape)
         for ii, i in enumerate(coords_ordered):
-            if '' not in props_ordered:
-                rest = rest + " ".join(map(str, i)) + " " + str(props_ordered) + "\n"
+
+            if self.show_props == True:
+                rest = (
+                    rest + " ".join(map(str, i)) + " " + str(props_ordered[ii]) + "\n"
+                )
             else:
-                rest = rest + " ".join(map(str, i))  + "\n"
+                rest = rest + " ".join(map(str, i)) + "\n"
+
         result = header + middle + rest
 
         return result
@@ -709,7 +566,10 @@ class Atoms(object):
     def __repr__(self):
         system = str(self.composition.reduced_formula)
         header = (
-            str(system)+str("\n1.0\n")
+
+            str(system)
+            + str("\n1.0\n")
+
             + str(self.lattice_mat[0][0])
             + " "
             + str(self.lattice_mat[0][1])
@@ -751,18 +611,181 @@ class Atoms(object):
                 + "\ndirect\n"
             )
         rest = ""
-        #print ('props_ordered',props_ordered)
+
+        # print ('props_ordered',props_ordered)
         # print ('repr',self.frac_coords, self.frac_coords.shape)
         for ii, i in enumerate(coords_ordered):
-            if '' not in props_ordered:
-                rest = rest + " ".join(map(str, i)) + " " + str(props_ordered) + "\n"
+            if self.show_props == True:
+                rest = (
+                    rest + " ".join(map(str, i)) + " " + str(props_ordered[ii]) + "\n"
+                )
             else:
-                rest = rest + " ".join(map(str, i))  + "\n"
-            #rest = rest + " ".join(map(str, i)) + " " + str(props_ordered[ii]) + "\n"
+                rest = rest + " ".join(map(str, i)) + "\n"
+
         result = header + middle + rest
         return result
 
 
+
+
+class VacuumPadding(object):
+    """
+    Adds vaccum padding to make 2D structure or making molecules
+    """
+
+    def __init__(self, atoms, vacuum=20.0):
+        self.atoms = atoms
+        self.vacuum = vacuum
+
+    def get_effective_2d_slab(self):
+        """
+        Adds 2D vacuum to a system
+        """
+        z_coord = []
+        for i in self.atoms.frac_coords:
+            tmp = i[2]
+            if i[2] >= 0.5:
+                tmp = i[2] - 1
+            elif i[2] < -0.5:
+                tmp = i[2] + 1
+            z_coord.append(tmp)
+
+        zmaxp = max(np.array(z_coord) * self.atoms.lattice_mat[2][2])
+        zminp = min(np.array(z_coord) * self.atoms.lattice_mat[2][2])
+        thickness = abs(zmaxp - zminp)
+        padding = self.vacuum + thickness
+
+        lattice_mat = self.atoms.lattice_mat
+        # lattice_mat[2][2] = padding
+        # elements = self.atoms.elements
+        # atoms = Atoms(lattice_mat = lattice_mat, coords = self.atoms.cart_coords, elements = elements, cartesian = True)
+        # atoms = atoms.center(vacuum=0.0)
+        new_lat = self.atoms.lattice_mat
+        a1 = new_lat[0]
+        a2 = new_lat[1]
+        a3 = new_lat[2]
+        new_lat = np.array(
+            [
+                a1,
+                a2,
+                np.cross(a1, a2)
+                * np.dot(a3, np.cross(a1, a2))
+                / norm(np.cross(a1, a2)) ** 2,
+            ]
+        )
+
+        a1 = new_lat[0]
+        a2 = new_lat[1]
+        a3 = new_lat[2]
+        # print("a1,a2,a3", new_lat)
+
+        latest_lat = np.array(
+            [
+                (np.linalg.norm(a1), 0, 0),
+                (
+                    np.dot(a1, a2) / np.linalg.norm(a1),
+                    np.sqrt(
+                        np.linalg.norm(a2) ** 2
+                        - (np.dot(a1, a2) / np.linalg.norm(a1)) ** 2
+                    ),
+                    0,
+                ),
+                (0, 0, np.linalg.norm(a3)),
+            ]
+        )
+        # latest_lat[2][2] = padding
+        M = np.linalg.solve(new_lat, latest_lat)
+        new_cart_coords = self.atoms.cart_coords
+        new_coords = np.dot(new_cart_coords, M)
+        new_atoms = Atoms(
+            lattice_mat=latest_lat,
+            elements=self.atoms.elements,
+            coords=new_coords,
+            cartesian=True,
+        )
+        frac_coords = new_atoms.frac_coords
+        frac_coords[:] = frac_coords[:] % 1
+        new_atoms = Atoms(
+            lattice_mat=latest_lat,
+            elements=self.atoms.elements,
+            coords=frac_coords,
+            cartesian=False,
+        )
+        new_lat = new_atoms.lattice_mat
+        new_cart_coords = new_atoms.cart_coords
+        elements = new_atoms.elements
+        new_lat[2][2] = padding  # new_lat[2][2]+ self.vacuum
+        with_vacuum_atoms = Atoms(
+            lattice_mat=new_lat,
+            elements=elements,
+            coords=new_cart_coords,
+            cartesian=True,
+        )
+        frac = np.array(with_vacuum_atoms.frac_coords)
+        frac[:, 2] = frac[:, 2] - np.mean(frac[:, 2]) + 0.5
+        frac[:, 2] = frac[:, 2] - np.mean(frac[:, 2]) + 0.5
+        with_vacuum_atoms = Atoms(
+            lattice_mat=new_lat, elements=elements, coords=frac, cartesian=False
+        )
+        return with_vacuum_atoms
+
+    def get_effective_molecule(self):
+        """
+        Adds vacuum around a system
+        """
+        x_coord = []
+        y_coord = []
+        z_coord = []
+        for i in self.atoms.frac_coords:
+            tmp = i[0]
+            if i[0] >= 0.5:
+                tmp = i[0] - 1
+            elif i[0] < -0.5:
+                tmp = i[0] + 1
+            x_coord.append(tmp)
+            tmp = i[1]
+            if i[1] >= 0.5:
+                tmp = i[1] - 1
+            elif i[1] < -0.5:
+                tmp = i[1] + 1
+            y_coord.append(tmp)
+            tmp = i[2]
+            if i[2] >= 0.5:
+                tmp = i[2] - 1
+            elif i[2] < -0.5:
+                tmp = i[2] + 1
+            z_coord.append(tmp)
+
+        xmaxp = max(np.array(x_coord) * self.atoms.lattice_mat[0][0])
+        xminp = min(np.array(x_coord) * self.atoms.lattice_mat[0][0])
+        ymaxp = max(np.array(y_coord) * self.atoms.lattice_mat[1][1])
+        yminp = min(np.array(y_coord) * self.atoms.lattice_mat[1][1])
+        zmaxp = max(np.array(z_coord) * self.atoms.lattice_mat[2][2])
+        zminp = min(np.array(z_coord) * self.atoms.lattice_mat[2][2])
+        thickness_x = abs(xmaxp - xminp)
+        thickness_y = abs(ymaxp - yminp)
+        thickness_z = abs(zmaxp - zminp)
+
+        lattice_mat = np.zeros((3, 3))  # self.atoms.lattice_mat
+        lattice_mat[0][0] = self.vacuum + thickness_x
+        lattice_mat[1][1] = self.vacuum + thickness_y
+        lattice_mat[2][2] = self.vacuum + thickness_z
+        elements = self.atoms.elements
+        atoms = Atoms(
+            lattice_mat=lattice_mat,
+            coords=self.atoms.cart_coords,
+            elements=elements,
+            cartesian=True,
+        )
+        frac = np.array(atoms.frac_coords)
+        frac[:, 0] = frac[:, 0] - np.mean(frac[:, 0]) + 0.5
+        frac[:, 1] = frac[:, 1] - np.mean(frac[:, 1]) + 0.5
+        frac[:, 2] = frac[:, 2] - np.mean(frac[:, 2]) + 0.5
+        with_vacuum_atoms = Atoms(
+            lattice_mat=lattice_mat, elements=elements, coords=frac, cartesian=False
+        )
+        return with_vacuum_atoms
+
 """
 if __name__ == "__main__":
     box = [[2.715, 2.715, 0], [0, 2.715, 2.715], [2.715, 0, 2.715]]
